summaryrefslogtreecommitdiffstats
path: root/kradio3/plugins/gui-quickbar/buttonflowlayout.h
diff options
context:
space:
mode:
Diffstat (limited to 'kradio3/plugins/gui-quickbar/buttonflowlayout.h')
-rw-r--r--kradio3/plugins/gui-quickbar/buttonflowlayout.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kradio3/plugins/gui-quickbar/buttonflowlayout.h b/kradio3/plugins/gui-quickbar/buttonflowlayout.h
index 3346c6d..fe33efc 100644
--- a/kradio3/plugins/gui-quickbar/buttonflowlayout.h
+++ b/kradio3/plugins/gui-quickbar/buttonflowlayout.h
@@ -1,7 +1,7 @@
/****************************************************************************
-** $Id: buttonflowlayout.h 471 2006-11-11 17:04:51Z emw $
+** $Id: buttonflowtqlayout.h 471 2006-11-11 17:04:51Z emw $
**
-** Definition of simple flow layout for custom layout example
+** Definition of simple flow tqlayout for custom tqlayout example
**
** Created : 979899
**
@@ -23,7 +23,7 @@
#include "../../src/include/utils.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqptrlist.h>
class ButtonFlowLayout : public TQLayout
@@ -41,9 +41,9 @@ public:
void addItem( TQLayoutItem *item);
bool hasHeightForWidth() const;
int heightForWidth( int ) const;
- TQSize sizeHint() const;
- TQSize minimumSize() const;
- TQSize minimumSize(const TQSize &r) const; // minimumSize is dependent from width
+ TQSize tqsizeHint() const;
+ TQSize tqminimumSize() const;
+ TQSize tqminimumSize(const TQSize &r) const; // tqminimumSize is dependent from width
TQLayoutIterator iterator();
TQSizePolicy::ExpandData expanding() const;